@@ -15,14 +15,14 @@ const AEAD2022_MAX_PADDING_SIZE: usize = 900;
 fn get_aead_2022_padding_size(payload: &[u8]) -> usize {
     use std::cell::RefCell;
 
-    use rand::{rngs::SmallRng, Rng, SeedableRng};
+    use rand::{Rng, SeedableRng, rngs::SmallRng};
 
     thread_local! {
-        static PADDING_RNG: RefCell<SmallRng> = RefCell::new(SmallRng::from_entropy());
+        static PADDING_RNG: RefCell<SmallRng> = RefCell::new(SmallRng::from_os_rng());
     }
 
     if payload.is_empty() {
-        PADDING_RNG.with(|rng| rng.borrow_mut().gen::<usize>() % AEAD2022_MAX_PADDING_SIZE)
+        PADDING_RNG.with(|rng| rng.borrow_mut().random_range::<usize, _>(0..=AEAD2022_MAX_PADDING_SIZE))
     } else {
         0
     }
